@@ -154,9 +154,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
               continue;
             }
             else {
-              // Add addede package names in this compile
-              SPVM_LIST_push(compiler->tmp_added_package_names, (void*)package_name);
-              
               // change :: to / and add ".spvm"
               int32_t cur_rel_file_length = (int32_t)(strlen(package_name) + 6);
               char* cur_rel_file = SPVM_COMPILER_ALLOCATOR_safe_malloc_zero(compiler, cur_rel_file_length + 1);
